@@ -18,7 +18,7 @@
 #
 # The Initial Developer of the Original Code is
 # Changwoo Ryu.
-# Portions created by the Initial Developer are Copyright (C) 2008, 2009
+# Portions created by the Initial Developer are Copyright (C) 2008, 2009, 2010
 # the Initial Developer. All Rights Reserved.
 #
 # Contributor(s): See CREDITS file
@@ -199,7 +199,8 @@ groups['-으시-'] = [
                 [u'-으시-', COND_T_NOT_RIEUL, '']],
       'after': ['#용언', '#이다'],
       'notafter': ['계시다', '모시다'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으시-', ['#용언']),
@@ -231,7 +232,8 @@ groups['-었-'] = [
                 ],
       'after': ['#용언', '#이다', '-으시-'],
       'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
-                  '#러불규칙', '#르불규칙', '#우불규칙', '#으불규칙'],
+                  '#러불규칙', '#르불규칙', '#우불규칙', '#으불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     { 'rules': [[u'-%s었-' % T_RIEUL, '[%s]%s' % (V_NOT_A_O, T_TIKEUT), T_TIKEUT],
@@ -344,7 +346,8 @@ groups['-어'] = [
                 ],
       'after': ['#용언', '-었-', '-겠-', '-으시-'],
       'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
-                  '#러불규칙', '#르불규칙', '#우불규칙', '#으불규칙'],
+                  '#러불규칙', '#르불규칙', '#우불규칙', '#으불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     { 'rules': [[u'-%s어' % T_RIEUL, '[%s]%s' % (V_NOT_A_O, T_TIKEUT), T_TIKEUT],
@@ -530,7 +533,8 @@ groups['-을'] = [
                 [u'-' + T_RIEUL, T_RIEUL, T_RIEUL],
                 [u'-을', COND_T_NOT_RIEUL, '']],
       'after': ['#용언', '#이다', '-으시-', '-시오-', '-었-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-을', ['#용언']),
@@ -556,7 +560,7 @@ groups['-을게'] = [
                 [u'-%s게' % T_RIEUL, T_RIEUL, T_RIEUL],
                 [u'-을게', COND_T_NOT_RIEUL, '']],
       'after': ['#동사'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-을게', ['#동사']),
@@ -655,7 +659,8 @@ groups['-은'] = [
                 [u'-은', COND_T_NOT_RIEUL, '']],
       'after': ['#용언', '#이다', '-으시-'],
       'notafter': ['^.*%s다$' % (V_I + T_SSANGSIOS), '^.*없다$'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-은', ['#용언']),
@@ -702,7 +707,8 @@ groups['-으며'] = [
     { 'rules': [[u'-며', COND_V_OR_RIEUL, ''],
                 [u'-으며', COND_T_NOT_RIEUL, '']],
       'after': ['#용언', '#이다', '-으시-', '-었-', '-겠-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으며', ['#용언']),
@@ -757,6 +763,13 @@ groups['-고도'] = [
     },
 ]
 
+#### 연결: -고서
+groups['-고서'] = [
+    { 'rules': [[u'-고서', '', '']],
+      'after': ['#용언', '#이다', '-으시-'],
+    },
+]
+
 #### 연결: -고자
 groups['-고자'] = [
     { 'rules': [[u'-고자', '', '']],
@@ -770,7 +783,8 @@ groups['-으세요'] = [
                 [u'-세요', T_RIEUL, T_RIEUL],
                 [u'-으세요', COND_T_NOT_RIEUL, '']],
       'after': ['#용언', '#이다'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으세요', ['#용언']),
@@ -784,7 +798,9 @@ groups['-으세요'] = [
 
 #### 연결: -거나
 groups['-거나'] = [
-    { 'rules': [[u'-거나', '', '']],
+    { 'rules': [[u'-거나', '', ''],
+                # 준말
+                [u'-건', '', '']],
       'after': ['#용언', '#이다', '-으시-', '-었-', '-겠-', '-으옵-'],
     },
 ]
@@ -794,7 +810,7 @@ groups['-으려'] = [
     { 'rules': [[u'-려', COND_V_OR_RIEUL, ''],
                 [u'-으려', COND_T_NOT_RIEUL, '']],
       'after': ['#동사', '-으시-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으려', ['#동사']),
@@ -861,7 +877,8 @@ groups['-으나'] = [
                 [u'-나', T_RIEUL, T_RIEUL],
                 [u'-으나', COND_T_NOT_RIEUL, '']],
       'after': ['#용언', '#이다', '-으시-', '-사오-', '-었-', '-겠-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으나', ['#용언']),
@@ -895,7 +912,7 @@ groups['-읍시다'] = [
                 [u'-%s시다' % T_PIEUP, T_RIEUL, T_RIEUL],
                 [u'-읍시다', COND_T_NOT_RIEUL, '']],
       'after': ['#동사', '-으시-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-읍시다', ['#동사']),
@@ -969,7 +986,7 @@ groups['-으라'] = [
     { 'rules': [[u'-라', COND_V_OR_RIEUL, ''],
                 [u'-으라', COND_T_NOT_RIEUL, '']],
       'after': ['#동사', '-으시-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으라', ['#동사']),
@@ -985,7 +1002,7 @@ groups['-으라고'] = [
     { 'rules': [[u'-라고', COND_V_OR_RIEUL, ''],
                 [u'-으라고', COND_T_NOT_RIEUL, '']],
       'after': ['#동사', '#이다', '아니다', '-으시-', '-더-', '-으리-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으라고', ['#동사']),
@@ -1004,7 +1021,7 @@ groups['-으라는'] = [
                 [u'-란', COND_V_OR_RIEUL, ''],
                 [u'-으란', COND_T_NOT_RIEUL, '']],
       'after': ['#동사', '#이다', '아니다', '-으시-', '-더-', '-으리-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으라는', ['#동사']),
@@ -1015,12 +1032,28 @@ groups['-으라는'] = [
     # 동사이므로 ㅎ불규칙 해당 없음
 ]
 
+#### 연결: -라면, -으라면 (라고 하면)
+groups['-으라면'] = [
+    { 'rules': [[u'-라면', COND_V_OR_RIEUL, ''],
+                [u'-으라면', COND_T_NOT_RIEUL, '']],
+      'after': ['#동사', '#이다', '아니다', '-으시-', '-더-', '-으리-'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#준말용언'],
+    },
+    # ㄷ불규칙
+    TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으라면', ['#동사']),
+    # ㅂ불규칙
+    PIEUP_IRREGULAR_TYPICAL_CLASS(u'-우라면', ['#동사']),
+    # ㅅ불규칙
+    SIOS_IRREGULAR_TYPICAL_CLASS(u'-으라면', ['#동사']),
+    # 동사이므로 ㅎ불규칙 해당 없음
+]
+
 #### 연결: -으래도,-래도 (라고 해도)
 groups['-으래도'] = [
     { 'rules': [[u'-래도', COND_V_OR_RIEUL, ''],
                 [u'-으래도', COND_T_NOT_RIEUL, '']],
       'after': ['#동사', '#이다', '아니다', '-으시-', '-더-', '-으리-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으래도', ['#동사']),
@@ -1038,7 +1071,8 @@ groups['-은데'] = [
                 [u'-은데', COND_T_NOT_RIEUL, '']],
       'after': ['#형용사', '#이다', '-으시-', '-사오-'],
       'notafter': ['^.*있다$', '^.*없다$'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-은데', ['#형용사']),
@@ -1071,7 +1105,8 @@ groups['-음'] = [
                 [u'-' + T_RIEUL_MIEUM, T_RIEUL, T_RIEUL],
                 [u'-음', COND_T_NOT_RIEUL, '']],
       'after': ['#용언', '#이다', '-으시-', '-었-', '-겠-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-음', ['#용언']),
@@ -1176,7 +1211,8 @@ groups['-으면'] = [
     { 'rules': [[u'-면', COND_V_OR_RIEUL, ''],
                 [u'-으면', COND_T_NOT_RIEUL, '']],
       'after': ['#용언', '#이다', '-으시-', '-었-', '-겠-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으면', ['#용언']),
@@ -1220,7 +1256,8 @@ groups['-은가'] = [
                 [u'-은가', COND_T_NOT_RIEUL, '']],
       'after': ['#형용사', '#이다', '-으시-'],
       'notafter': ['^.*있다$', '^.*없다$'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-은가', ['#형용사']),
@@ -1239,7 +1276,8 @@ groups['-으니까'] = [
                 [u'-니까', T_RIEUL, T_RIEUL],
                 [u'-으니까', COND_T_NOT_RIEUL, '']],
       'after': ['#용언', '#이다', '-으시-', '-오-', '-더-', '-었-', '-겠-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으니까', ['#용언']),
@@ -1273,7 +1311,8 @@ groups['-은지'] = [
                 [u'-은지', COND_T_NOT_RIEUL, '']],
       'after': ['#이다', '#형용사', '-으시-'],
       'notafter': ['^.*있다$', '^.*없다$'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-은지', ['#형용사']),
@@ -1292,7 +1331,7 @@ groups['-으십시오'] = [
                 [u'-십시오', T_RIEUL, T_RIEUL],
                 [u'-으십시오', COND_T_NOT_RIEUL, '']],
       'after': ['#동사'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으십시오', ['#동사']),
@@ -1308,7 +1347,8 @@ groups['-으므로'] = [
     { 'rules': [[u'-므로', COND_V_OR_RIEUL, ''],
                 [u'-으므로', COND_T_NOT_RIEUL, '']],
       'after': ['#용언', '#이다', '-으시-', '-었-', '-겠-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으므로', ['#용언']),
@@ -1355,7 +1395,7 @@ groups['-으러'] = [
     { 'rules': [[u'-러', COND_V_OR_RIEUL, ''],
                 [u'-으러', COND_T_NOT_RIEUL, '']],
       'after': ['#동사', '-으시-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으러', ['#동사']),
@@ -1382,7 +1422,8 @@ groups['-으니'] = [
                 [u'-니', T_RIEUL, T_RIEUL],
                 [u'-으니', COND_T_NOT_RIEUL, '']],
       'after': ['#용언', '#이다', '-으시-', '-었-', '-겠-', '-오-', '-더-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으니', ['#용언']),
@@ -1431,7 +1472,8 @@ groups['-으냐'] = [
                 [u'-으냐', COND_T_NOT_RIEUL, '']],
       'after': ['#형용사', '#이다'],
       'notafter': ['^.*있다$', '^.*없다$'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # NOTE: 어간과 결합하지 않고 '-었-' 및 '-겠-' 선어말 어미와 결합할
     # 경우에는 받침이 있음에도 "-었으냐", "-겠느냐"가 아니라 "-었냐",
@@ -1619,7 +1661,8 @@ groups['-으오'] = [
                 [u'-오', T_RIEUL, T_RIEUL],
                 [u'-으오', COND_T_NOT_RIEUL, '']],
       'after': ['#용언', '#이다', '-으시-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으오', ['#용언']),
@@ -1666,7 +1709,7 @@ groups['-으라니'] = [
     { 'rules': [[u'-라니', COND_V_OR_RIEUL, ''],
                 [u'-으라니', COND_T_NOT_RIEUL, '']],
       'after': ['#동사', '#이다', '아니다', '-으시-', '-더-', '-으리-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으라니', ['#동사']),
@@ -1699,7 +1742,8 @@ groups['-으리라'] = [
     { 'rules': [[u'-리라', COND_V_OR_RIEUL, ''],
                 [u'-으리라', COND_T_NOT_RIEUL, '']],
       'after': ['#용언', '-으시', '-었-', '-겠-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으리라', ['#용언']),
@@ -1716,7 +1760,8 @@ groups['-으려니'] = [
     { 'rules': [[u'-려니', COND_V_OR_RIEUL, ''],
                 [u'-으려니', COND_T_NOT_RIEUL, '']],
       'after': ['#용언', '#이다', '-으시-', '-었-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으려니', ['#용언']),
@@ -1742,7 +1787,7 @@ groups['-으라네'] = [
                 [u'-라네', T_RIEUL, T_RIEUL],
                 [u'-으라네', COND_T_NOT_RIEUL, '']],
       'after': ['#동사', '#이다', '아니다', '-으시-', '-더-', '-으리-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-으라네', ['#동사']),
@@ -1777,7 +1822,8 @@ groups['-을는지'] = [
                 [u'-%s는지' % T_RIEUL, T_RIEUL, T_RIEUL],
                 [u'-을는지', COND_T_NOT_RIEUL, '']],
       'after': ['#용언', '#이다', '-으시-', '-었-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-을는지', ['#용언']),
@@ -1834,9 +1880,9 @@ groups['-느라고'] = [
 groups['-을래'] = [
     { 'rules': [[u'-%s래' % T_RIEUL, COND_V_ALL, ''],
                 [u'-%s래' % T_RIEUL, T_RIEUL, T_RIEUL],
-                [u'-을래', COND_NOT_RIEUL, '']],
+                [u'-을래', COND_T_NOT_RIEUL, '']],
       'after': ['#동사'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-을래', ['#동사']),
@@ -1868,9 +1914,10 @@ groups['-는답니다'] = [
 groups['-을세'] = [
     { 'rules': [[u'-%s세' % T_RIEUL, COND_V_ALL, ''],
                 [u'-%s세' % T_RIEUL, T_RIEUL, T_RIEUL],
-                [u'-을세', COND_NOT_RIEUL, '']],
+                [u'-을세', COND_T_NOT_RIEUL, '']],
       'after': ['#용언', '#이다', '-으시-', '-었-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-을세', ['#용언']),
@@ -1893,9 +1940,10 @@ groups['-요'] = [
 groups['-을라'] = [
     { 'rules': [[u'-%s라' % T_RIEUL, COND_V_ALL, ''],
                 [u'-%s라' % T_RIEUL, T_RIEUL, T_RIEUL],
-                [u'-을라', COND_NOT_RIEUL, '']],
+                [u'-을라', COND_T_NOT_RIEUL, '']],
       'after': ['#용언', '#이다', '-으시-', '-었-'],
-      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙'],
+      'notcond': ['#ㄷ불규칙', '#ㅂ불규칙', '#ㅅ불규칙', '#ㅎ불규칙',
+                  '#준말용언'],
     },
     # ㄷ불규칙
     TIKEUT_IRREGULAR_TYPICAL_CLASS(u'-을라', ['#용언']),
@@ -1917,3 +1965,36 @@ groups['-건대'] = [
       'after': ['#동사'],
     },
 ]
+
+#### 종결: -ㄴ대, -는대
+groups['-는대'] = [
+    { 'rules': [[u'-%s대' % T_NIEUN, COND_V_ALL, ''],
+                [u'-%s대' % T_NIEUN, T_RIEUL, T_RIEUL],
+                [u'-는대', COND_T_NOT_RIEUL, '']],
+      'after': ['#동사', '-으시-'],
+    },
+]
+
+#### 종결: -데
+groups['-데'] = [
+    { 'rules': [[u'-데', COND_V_ALL, '']],
+      'after': ['#용언', '#이다', '-으시-', '-었-', '-겠-'],
+    },
+]
+
+#### 종결: -마, -으마
+groups['-으마'] = [
+    { 'rules': [[u'-마', COND_V_ALL, ''],
+                [u'-마', T_RIEUL, T_RIEUL],
+                [u'-으마', COND_T_NOT_RIEUL, '']],
+      'after': ['#동사'],
+    },
+]
+
+#### 연결: -던지
+groups['-던지'] = [
+    { 'rules': [[u'-던지', COND_V_ALL, '']],
+      'after': ['#용언', '#이다', '-으시-', '-었-', '-겠-'],
+    },
+]
+
